@@ -1,22 +1,15 @@
-from PuzzleLib.Backend.Dnn.Rnn import deviceSupportsBatchHint
-from PuzzleLib.Datasets import IMDBLoader
+from PuzzleLib.Backend import Dnn
 
-from PuzzleLib.Containers import *
-from PuzzleLib.Modules import *
-from PuzzleLib.Handlers import *
+from PuzzleLib.Containers import Sequential
+from PuzzleLib.Modules import Embedder, SwapAxes, RNN, Concat, Dropout, Linear
+
+from PuzzleLib.Datasets import IMDBLoader
+from PuzzleLib.Handlers import Trainer, Validator
 from PuzzleLib.Optimizers import Adam
 from PuzzleLib.Cost import BCE
 
 
-def main():
-	hintBatchsize, batchsize = (40, 40) if deviceSupportsBatchHint() else (None, 32)
-	numwords, maxlen = 20000, 100
-
-	imdb = IMDBLoader(numwords=numwords, maxlen=maxlen)
-	data, labels, _ = imdb.load(path="../TestData/")
-	data, labels = data[:], labels[:]
-	print("Loaded IMDB")
-
+def buildNet(numwords, maxlen, hintBatchsize):
 	seq = Sequential()
 	seq.append(Embedder(numwords, maxlen, 128, initscheme="uniform", wscale=0.05, learnable=True))
 
@@ -27,19 +20,34 @@ def main():
 	seq.append(Dropout(p=0.5))
 
 	seq.append(Linear(128, 1))
+	return seq
+
+
+def main():
+	hintBatchsize, batchsize = (40, 40) if Dnn.deviceSupportsBatchHint() else (None, 32)
+	numwords, maxlen = 20000, 100
+
+	imdb = IMDBLoader(numwords=numwords, maxlen=maxlen)
+	data, labels, _ = imdb.load(path="../TestData/")
+	data, labels = data[:], labels[:]
+	print("Loaded IMDB")
+
+	net = buildNet(numwords, maxlen, hintBatchsize)
 
 	optimizer = Adam(alpha=1e-3)
-	optimizer.setupOn(seq, useGlobalState=True)
+	optimizer.setupOn(net, useGlobalState=True)
 
 	cost = BCE()
-	trainer = Trainer(seq, cost, optimizer, batchsize=batchsize)
-	validator = Validator(seq, cost, batchsize=batchsize)
+	trainer = Trainer(net, cost, optimizer, batchsize=batchsize)
+	validator = Validator(net, cost, batchsize=batchsize)
 
 	print("Started training ...")
 
 	for i in range(15):
-		trainer.trainFromHost(data[:25000], labels[:25000], macroBatchSize=25000,
-							  onMacroBatchFinish=lambda train: print("Train error: %s" % train.cost.getMeanError()))
+		trainer.trainFromHost(
+			data[:25000], labels[:25000], macroBatchSize=25000,
+			onMacroBatchFinish=lambda train: print("Train error: %s" % train.cost.getMeanError())
+		)
 		print("Accuracy: %s" % (1.0 - validator.validateFromHost(data[25000:], labels[25000:], macroBatchSize=25000)))
 
 
